.. _signal_analysis.snr:

Signal‑to‑Noise Ratio
=====================

.. automodule:: eyetrace.signal_analysis.snr
   :members:
   :undoc-members:
   :show-inheritance:

SNR estimation methods help quantify the quality of a signal. The module
provides both a simple mean‑to‑std ratio and a smooth‑based method that
estimates noise as the difference between the original and a smoothed
version.